<?php
/* Copyright (C) 2015-2022	Charlene BENKE	<charlene@patas-monkey.com>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */

/**
 *	  \file	   htdocs/myfield/card.php
 *	  \ingroup	myfield
 *		\brief	  myfield card 
 */

$res=@include("../main.inc.php");					// For root directory
if (! $res && file_exists($_SERVER['DOCUMENT_ROOT']."/main.inc.php"))
	$res=@include($_SERVER['DOCUMENT_ROOT']."/main.inc.php"); // Use on dev env only
if (! $res) $res=@include("../../main.inc.php");		// For "custom" directory

require_once DOL_DOCUMENT_ROOT.'/core/class/html.formother.class.php';

require_once 'core/lib/myfield.lib.php';
require_once 'class/myfield.class.php';
require_once 'class/myfield_value.class.php';

$langs->load("myfield@myfield");

$rowid	= GETPOST('rowid', 'int');
$valueid= GETPOST('line', 'int');

$action = GETPOST('action', 'alpha');
$cancel = GETPOST('cancel', 'alpha');

$testvalue		=GETPOST("testvalue", "alpha");
$fontcolor		=GETPOST("fontcolor", "alpha");
$backgroundcolor=GETPOST("backgroundcolor", "alpha");
$replacement	=GETPOST("replacement", "none");

// Security check
if (!$user->rights->myfield->lire) accessforbidden();

/*
 *	Actions
 */
// Initialize technical object to manage hooks of myfield. Note that conf->hooks_modules contains array array
$hookmanager->initHooks(array('myfieldcard','globalcard'));

/*
 *	Actions
 */
if ($action == 'add' ) {
	if (! $cancel) {

		$object = new MyfieldValue($db);
		$object->fk_myfield			= $rowid;
		$object->testvalue			= trim($testvalue);
		$object->fontcolor	 		= trim($fontcolor);
		$object->backgroundcolor	= trim($backgroundcolor);
		$object->replacement	 	= trim($replacement);

		if ($object->testvalue) {
			$id=$object->create($user);
			if ($id > 0) {
				$action = "";
			} else {
				$mesg=$object->error;
				$action = 'create';
			}
		} else {
			$mesg=$langs->trans("ErrorFieldRequired", $langs->transnoentities("TestValue"));
			$action = 'create';
		}
	}
}

if ($action == 'update' ) {
	if (! $cancel) {
		$object = new MyfieldValue($db);
		$object->id				= $valueid;
		$object->testvalue		= trim($testvalue);
		$object->color	 		= trim($fontcolor);
		$object->bgcolor		= trim($backgroundcolor);
		$object->replacement	= trim($replacement);

		$object->update($user);
		
		header("Location: ".$_SERVER["PHP_SELF"]."?rowid=".$rowid);
		exit;
	}
}

if ($action == 'delete' ) {
	$object = new MyfieldValue($db);
	$object->delete($valueid);
	header("Location: ".$_SERVER["PHP_SELF"]."?rowid=".$rowid);
}



/*
 * View
 */

llxHeader('', $langs->trans("myField"), 'https://wiki.patas-monkey.com/index.php?title=MyField');

$form=new Form($db);
$formother=new FormOther($db);

$myfield = new Myfield($db);
$myfield->fetch($rowid);

$head = myField_prepare_head($myfield);
dol_fiche_head($head, 'value', $langs->trans("myField"), -1, 'myfield@myfield');

// on affiche les infos de l'objet courant dans le bandeau
$linkback = '<a href="list.php">'.$langs->trans("BackToList").'</a>';

$morehtmlref='<div class="refidno">';
$morehtmlref.=$langs->trans("myFieldLabel").' : '.$myfield->label;
$morehtmlref.='<br>'.$langs->trans("TypeOfMyField").' : '.ShowMyFieldType($myfield->typefield);
$morehtmlref.='</div>';

dol_banner_tab($myfield, 'rowid', $linkback, 1, 'rowid', 'rowid', $morehtmlref);

print '<div class="fichecenter">';
//print '<div class="fichehalfleft">';
print '<div class="underbanner clearboth"></div>';


// List of myfield Value
if (! $valueid && $action != 'create' && $action != 'edit') {
	$sql = "SELECT * FROM ".MAIN_DB_PREFIX."myfield_value as d";
	$sql.= " WHERE d.fk_myfield=".$rowid;
	// $sql.= " ORDER BY d.active, d.label";
	$result = $db->query($sql);
	if ($result) {
		$num = $db->num_rows($result);
		$i = 0;
		$permissiontoadd=true;
		// bouton de création d'un paramètre
		if ((int) DOL_VERSION > 10)
			$newcardbutton = dolGetButtonTitle($langs->trans('New'), '', 'fa fa-plus-circle', dol_buildpath('/myfield/value.php?rowid='.$rowid.'&action=create', 1).'?token='.newtoken().'&action=create', '', $permissiontoadd);
		else
			$newcardbutton = '<a href="'.dol_buildpath('/myfield/value.php?rowid='.$rowid, 1).'&action=create'.'">'.$langs->trans('New')."</a>";

		print_barre_liste($langs->trans('ValuesList'), 0, $_SERVER["PHP_SELF"], "", "", "", "",
			0, $num, 'title_setup', 0, $newcardbutton);



		print '<table class="border tableforfield" width="100%">';
		print '<tr class="liste_titre">';
		print '<td align="left">'.$langs->trans("Condition").'</td>';
		print '<td align="center">'.$langs->trans("FontColor").'</td>';
		print '<td align="center">'.$langs->trans("BackgroundColor").'</td>';
		print '<td align="right">'.$langs->trans("ReplacementText").'</td>';
		print '<td>&nbsp;</td>';
		print "</tr>\n";

		while ($i < $num) {
			$objp = $db->fetch_object($result);
			print "<tr >";
			print '<td><a href="'.$_SERVER["PHP_SELF"].'?action=edit&token='.newtoken().'&rowid='.$rowid.'&line='.$objp->rowid.'">';
			print img_object($langs->trans("ShowType"), 'value@myfield').' '.$objp->testvalue.'</a></td>';
			print '<td align=center>';
			print $formother->showColor($objp->color, '');
			print '</td>';
			print '<td align=center>';
			print $formother->showColor($objp->bgcolor, '');
			print '</td>';
			print '<td align="right">'.$objp->replacement.'</td>';
			print '<td align="right">';
			print '<a href="'.$_SERVER["PHP_SELF"].'?action=delete&token='.newtoken().'&rowid='.$rowid.'&line='.$objp->rowid.'">'.img_delete().'</a>';
			print "</td></tr>";
			$i++;
		}
		print "</table>";
	} else
		dol_print_error($db);


}


/* ************************************************************************** */
/*																			*/
/* Creation mode															  */
/*																			*/
/* ************************************************************************** */
if ($action == 'create') {
	$object = new MyfieldValue($db);

	print '<form action="'.$_SERVER['PHP_SELF'].'" method="POST">';
	print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
	print '<input type="hidden" name="action" value="add">';
	print '<input type="hidden" name="rowid" value="'.$rowid.'">';

	dol_fiche_head('');

	print '<table class="border" width="100%">';
	print '<tbody>';

	print '<tr><td width="25%" class="fieldrequired">'.$langs->trans("ActivateTest").'</td>';
	print '<td><input type="text" name="testvalue" size=80></td></tr>';

	print '<tr><td>'.$langs->trans("FontColor").'</td>';
	print '<td>';
	print $formother->selectColor("", 'fontcolor', null, 1, '', 'hideifnotset');
	print '</td></tr>';
	print '<tr><td>'.$langs->trans("BackgroundColor").'</td>';
	print '<td>';
	print $formother->selectColor("", 'backgroundcolor', null, 1, '', 'hideifnotset');
	print '</td></tr>';

	print '<tr><td >'.$langs->trans("Remplacement").'</td>';
	print '<td><input type="text" name="replacement"></td></tr>';


	print '<tbody>';
	print "</table>\n";

	dol_fiche_end();

	print '<div class="center">';
	print '<input type="submit" name="button" class="button" value="'.$langs->trans("Add").'">';
	print '&nbsp;&nbsp;&nbsp;&nbsp;&nbsp;';
	print '<input type="submit" name="cancel" class="button" value="'.$langs->trans("Cancel").'" onclick="history.go(-1)" />';
	print '</div>';

	print "</form>\n";
}

/* ************************************************************************** */
/*																			*/
/* View mode																  */
/*																			*/
/* ************************************************************************** */
if ($valueid > 0) {
	if ($action != 'edit') {
		$object = new MyfieldValue($db);
		$object->fetch($rowid);

		print '<table class="border tableforfield" width="100%">';
		// Ref
		print '<tr><td width="15%">'.$langs->trans("Ref").'</td>';
		print '<td>';
		print $form->showrefnav($object, 'rowid', "");
		print '</td></tr>';

		// Label
		print '<tr><td width="15%">'.$langs->trans("Label").'</td>';
		print '<td>'.dol_escape_htmltag($object->label).'</td></tr>';

		print '<tr><td>'.$langs->trans("ColorType").'</td>';
		print '<td>';
		print $formother->showColor($object->color, '');
		
		print '</td></tr>';

		print '<tr><td>'.$langs->trans("Active").'</td>';
		print '<td align="left">'.yn($object->active).'</td>';

		print '</table>';

		dol_fiche_end();


		print '<div class="tabsAction">';

		// Edit
		print '<div class="inline-block divButAction">';
		print '<a class="butAction" href="'.$_SERVER['PHP_SELF'].'?action=edit&amp;rowid='.$object->id.'">';
		print $langs->trans("Modify").'</a></div>';
		print '<div class="inline-block divButAction">';
		print '<a class="butActionDelete" href="'.$_SERVER['PHP_SELF'].'?action=delete&rowid='.$object->id.'">';
		print $langs->trans("DeleteType").'</a></div>';
		print "</div>";
	}

	/* ************************************************************************** */
	/*																			*/
	/* Edition mode															   */
	/*																			*/
	/* ************************************************************************** */

	if ($action == 'edit') {
		$object = new MyfieldValue($db);
		$object->id = $valueid;
		$object->fetch($valueid);
		//var_dump($object);
		$head = array();

		print '<form method="post" action="'.$_SERVER["PHP_SELF"].'?rowid='.$rowid.'">';
		print '<input type="hidden" name="token" value="'.$_SESSION['newtoken'].'">';
		print '<input type="hidden" name="rowid" value="'.$rowid.'">';
		print '<input type="hidden" name="line" value="'.$valueid.'">';
		print '<input type="hidden" name="action" value="update">';

		dol_fiche_head('', $langs->trans("EditmyFieldValue"));

		print '<table class="border" width="100%">';

		print '<tr><td width="15%">'.$langs->trans("Condition").'</td>';
		print '<td><input type="text" name="testvalue" size="40" value="'.dol_escape_htmltag($object->testvalue).'"></td></tr>';

		print '<tr><td>'.$langs->trans("FontColor").'</td>';
		print '<td>';
		print $formother->selectColor($object->color, 'fontcolor', null, 1, '', 'hideifnotset');
		print '</td></tr>';

		print '<tr><td>'.$langs->trans("BackgroundColor").'</td>';
		print '<td>';
		print $formother->selectColor($object->bgcolor, 'backgroundcolor', null, 1, '', 'hideifnotset');
		print '</td></tr>';

		print '<tr><td width="15%">'.$langs->trans("RemplacementText").'</td>';
		print '<td><input type="text" name="replacement" size="40" value="'.$object->replacement.'"></td></tr>';


		print '</table>';

		dol_fiche_end();

		print '<div class="center">';
		print '<input type="submit" class="butAction" value="'.$langs->trans("Save").'">';
		print '<input type="submit" name="button" class="butAction" value="'.$langs->trans("Cancel").'">';
		print '</div>';

		print "</form>";
	}
}

llxFooter();
$db->close();

// pour empecher le trigger de myfield de s'activer...
function llxFooter() 
{ 
}